/*
 * Asterisk -- A telephony toolkit for Linux.
 *
 * Setting a tone zone for a channel
 * 
 * Coded by Olle E. Johansson, oej@edvina.net
 *
 * Copyright (C) 2005, Digium, Inc.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License
 */

#include <stdlib.h>
#include <string.h>
#include <sys/types.h>

#include "asterisk.h"

/* ASTERISK_FILE_VERSION(__FILE__, "$Revision: 1.2 $") */

#include "asterisk/channel.h"
#include "asterisk/pbx.h"
#include "asterisk/logger.h"
#include "asterisk/utils.h"
#include "asterisk/indications.h"
#include "asterisk/app.h"

static char *builtin_function_country(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) 
{
	struct tone_zone *new_zone;

	if (data && !ast_strlen_zero(data)) {
		new_zone = ast_get_indication_zone(data);
		if (!new_zone) {
			ast_log(LOG_ERROR, "Unknown country code, check indications.conf for available country codes!\n");
			return NULL;
		}
		chan->zone = new_zone;
	}
	if (chan->zone)
		ast_copy_string(buf, chan->zone->country, len);
	else {
		new_zone = ast_get_indication_zone(NULL);
		if (new_zone)
			ast_copy_string(buf, new_zone->country, len);
		else
			return NULL;
	}
	return buf;
}

#ifndef BUILTIN_FUNC
static
#endif
struct ast_custom_function country_function = {
	.name = "COUNTRY",
	.synopsis = "Gets or sets the channel's indication zone by country code.",
	.syntax = "COUNTRY([<country code>])",
	.desc = "Gets or sets the channel indication country.  This information\n"
	"is used for generating different tones (dial, busy etc) in Asterisk.\n"
	"Please observe that this setting does not change zaptel tones or tones\n"
	"generated by VoIP phones. Default country is set in indications.conf.\n"
	"Always returns the country code for the indications used for this channel.\n",
	.read = builtin_function_country,
};

